# This file was auto-generated by Fern from our API Definition.

from ..core.api_error import ApiError
from ..types.file_fetch_error import FileFetchError


class NotFoundError(ApiError):
    def __init__(self, body: FileFetchError):
        super().__init__(status_code=404, body=body)
